--
## Project Description

The project provides a collection of automation tools for commonly used EDA and cleaning techniques. 

The package consists of three modules, 

1. EDA - Contains a class which provides automation for detecting datat types, listing null values, identifying redundant entries, basic data analysis among others

2. clean - Contains a class which provides options for the user to perform cleaning tasks such as cleaning string columns, downcasting data types, assigning proper data types, making certain entries as na as necessary, dropping duplicates. More importantly it also tracks all the changes made in a easy to read format and the rows and columns it impacted so that the user can easily keep track of changes. 

3. chart - Contains functions for plotting purposes with embedded formatting.

This is an open-source project. Contributors are welcome. :) 
